==> zio-aws-lookoutequipment_2.12-5.17.145.1-sources.jar: zio/aws/lookoutequipment/model/IngestionS3InputConfiguration.scala <==
package zio.aws.lookoutequipment.model
import zio.ZIO
import zio.aws.lookoutequipment.model.primitives.{S3Prefix, S3Bucket}
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class IngestionS3InputConfiguration(
    bucket: S3Bucket,
    prefix: Option[S3Prefix] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lookoutequipment.model.IngestionS3InputConfiguration = {
    import IngestionS3InputConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lookoutequipment.model.IngestionS3InputConfiguration
      .builder()
      .bucket(S3Bucket.unwrap(bucket): java.lang.String)
      .optionallyWith(
        prefix.map(value => S3Prefix.unwrap(value): java.lang.String)
      )(_.prefix)
      .build()
  }
  def asReadOnly
      : zio.aws.lookoutequipment.model.IngestionS3InputConfiguration.ReadOnly =
    zio.aws.lookoutequipment.model.IngestionS3InputConfiguration
      .wrap(buildAwsValue())
}
object IngestionS3InputConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lookoutequipment.model.IngestionS3InputConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.lookoutequipment.model.IngestionS3InputConfiguration =
      zio.aws.lookoutequipment.model
        .IngestionS3InputConfiguration(bucket, prefix.map(value => value))
    def bucket: S3Bucket
    def prefix: Option[S3Prefix]
    def getBucket: ZIO[Any, Nothing, S3Bucket] = ZIO.succeed(bucket)
    def getPrefix: ZIO[Any, AwsError, S3Prefix] =
      AwsError.unwrapOptionField("prefix", prefix)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lookoutequipment.model.IngestionS3InputConfiguration
  ) extends zio.aws.lookoutequipment.model.IngestionS3InputConfiguration.ReadOnly {
    override val bucket: S3Bucket =
      zio.aws.lookoutequipment.model.primitives.S3Bucket(impl.bucket())
    override val prefix: Option[S3Prefix] = scala
      .Option(impl.prefix())
      .map(value => zio.aws.lookoutequipment.model.primitives.S3Prefix(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.lookoutequipment.model.IngestionS3InputConfiguration
  ): zio.aws.lookoutequipment.model.IngestionS3InputConfiguration.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-lookoutequipment_2.12-5.20.7.3-sources.jar: zio/aws/lookoutequipment/model/IngestionS3InputConfiguration.scala <==
package zio.aws.lookoutequipment.model
import zio.ZIO
import zio.aws.lookoutequipment.model.primitives.{
  KeyPattern,
  S3Prefix,
  S3Bucket
}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class IngestionS3InputConfiguration(
    bucket: S3Bucket,
    prefix: Optional[S3Prefix] = Optional.Absent,
    keyPattern: Optional[KeyPattern] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lookoutequipment.model.IngestionS3InputConfiguration = {
    import IngestionS3InputConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lookoutequipment.model.IngestionS3InputConfiguration
      .builder()
      .bucket(S3Bucket.unwrap(bucket): java.lang.String)
      .optionallyWith(
        prefix.map(value => S3Prefix.unwrap(value): java.lang.String)
      )(_.prefix)
      .optionallyWith(
        keyPattern.map(value => KeyPattern.unwrap(value): java.lang.String)
      )(_.keyPattern)
      .build()
  }
  def asReadOnly
      : zio.aws.lookoutequipment.model.IngestionS3InputConfiguration.ReadOnly =
    zio.aws.lookoutequipment.model.IngestionS3InputConfiguration
      .wrap(buildAwsValue())
}
object IngestionS3InputConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lookoutequipment.model.IngestionS3InputConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.lookoutequipment.model.IngestionS3InputConfiguration =
      zio.aws.lookoutequipment.model.IngestionS3InputConfiguration(
        bucket,
        prefix.map(value => value),
        keyPattern.map(value => value)
      )
    def bucket: S3Bucket
    def prefix: Optional[S3Prefix]
    def keyPattern: Optional[KeyPattern]
    def getBucket: ZIO[Any, Nothing, S3Bucket] = ZIO.succeed(bucket)
    def getPrefix: ZIO[Any, AwsError, S3Prefix] =
      AwsError.unwrapOptionField("prefix", prefix)
    def getKeyPattern: ZIO[Any, AwsError, KeyPattern] =
      AwsError.unwrapOptionField("keyPattern", keyPattern)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lookoutequipment.model.IngestionS3InputConfiguration
  ) extends zio.aws.lookoutequipment.model.IngestionS3InputConfiguration.ReadOnly {
    override val bucket: S3Bucket =
      zio.aws.lookoutequipment.model.primitives.S3Bucket(impl.bucket())
    override val prefix: Optional[S3Prefix] = zio.aws.core.internal
      .optionalFromNullable(impl.prefix())
      .map(value => zio.aws.lookoutequipment.model.primitives.S3Prefix(value))
    override val keyPattern: Optional[KeyPattern] = zio.aws.core.internal
      .optionalFromNullable(impl.keyPattern())
      .map(value => zio.aws.lookoutequipment.model.primitives.KeyPattern(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.lookoutequipment.model.IngestionS3InputConfiguration
  ): zio.aws.lookoutequipment.model.IngestionS3InputConfiguration.ReadOnly =
    new Wrapper(impl)
}
